==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/VoidEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescription } from "./VoidEventArgsDescription";
/**
 * @hidden
 */
export let VoidEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class VoidEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (VoidEventArgsDescriptionMetadata.a == null) {
                VoidEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VoidEventArgsDescriptionMetadata.c(VoidEventArgsDescriptionMetadata.a);
            }
            if (a.j(VoidEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(VoidEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            VoidEventArgsDescriptionMetadata.b(a);
            a.aa("VoidEventArgs", () => new VoidEventArgsDescription());
            a.z("VoidEventArgs", VoidEventArgsDescriptionMetadata.a);
        }
    }
    VoidEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(VoidEventArgsDescriptionMetadata, 'VoidEventArgsDescriptionMetadata');
    VoidEventArgsDescriptionMetadata.a = null;
    return VoidEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/VoidEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescription } from "./VoidEventArgsDescription";
/**
 * @hidden
 */
export let VoidEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class VoidEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (VoidEventArgsDescriptionMetadata.a == null) {
                VoidEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                VoidEventArgsDescriptionMetadata.c(VoidEventArgsDescriptionMetadata.a);
            }
            if (a.k(VoidEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(VoidEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            VoidEventArgsDescriptionMetadata.b(a);
            a.ac("VoidEventArgs", () => new VoidEventArgsDescription());
            a.ab("VoidEventArgs", VoidEventArgsDescriptionMetadata.a);
        }
    }
    VoidEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(VoidEventArgsDescriptionMetadata, 'VoidEventArgsDescriptionMetadata');
    VoidEventArgsDescriptionMetadata.a = null;
    return VoidEventArgsDescriptionMetadata;
})();
